@@ -11,6 +11,10 @@ RGEOSBinPredFunc = function(spgeom1, spgeom2, byid, func, optparam=NULL) {
     if(!is.null(spgeom1) & !is.null(spgeom2)) {
         if(!identical(spgeom1@proj4string,spgeom2@proj4string))
             warning("spgeom1 and spgeom2 have different proj4 strings")
+        if (inherits(spgeom1, "SpatialPolygons")) 
+            spgeom1 <- createSPComment(spgeom1)
+        if (inherits(spgeom2, "SpatialPolygons")) 
+            spgeom2 <- createSPComment(spgeom2)
     }
 	
     if ( func == "rgeos_equalsexact" | func == "rgeos_relatepattern" ) {
